@@ -1,9 +1,9 @@
 #include <config.h>
 #include <gdk/gdk.h>
+#include <math.h>
 #include <gnome.h>
 #include <applet-widget.h>
 #include <stdio.h>
-#include <math.h>
 #include <fcntl.h>
 #include <locale.h>
 #include "asclock.h"
@@ -35,8 +35,6 @@ void about_dialog(AppletWidget *applet, gpointer data)
         gtk_widget_show (about);
 
         return;
-	applet = NULL;
-	data = NULL;
 }
 
 static GtkWidget * properties_timezone_render(asclock *my_asclock, GtkWidget *parent, float lat, float lon)
@@ -52,18 +50,20 @@ static GtkWidget * properties_timezone_render(asclock *my_asclock, GtkWidget *pa
   do {
 	  
 	  fname = tempnam(NULL, "asclock_globe");
-	  fd = open (fname, O_CREAT | O_EXCL, 0777);
+	  fd = open (fname, O_CREAT | O_EXCL, 0600);
   } while (fd == -1);
 
   close (fd);
   
-  old_locale = setlocale(LC_NUMERIC, "C");
+  old_locale = g_strdup (setlocale(LC_NUMERIC, NULL));
+  setlocale(LC_NUMERIC, "C");
   g_snprintf(cmd, sizeof(cmd), 
 	     "xearth -ppm -night 15 -size '320 320' -mag 0.95 -pos 'fixed 0 %.4f' -nostars >> %s",
 	     lon, fname);
 
   system(cmd);
   setlocale(LC_NUMERIC, old_locale);
+  g_free (old_locale);
 
   gdk_imlib_load_file_to_pixmap(fname, &pmap, &mask);
 
@@ -88,7 +88,6 @@ static GtkWidget * properties_timezone_render(asclock *my_asclock, GtkWidget *pa
   unlink(fname);
   free(fname);
   return NULL;
-  parent = NULL;
 }
 
 static void theme_selected(GtkWidget *list, gint row, gint column, GdkEventButton *event, gpointer data)
@@ -100,12 +99,11 @@ static void theme_selected(GtkWidget *list, gint row, gint column, GdkEventButto
   gtk_clist_get_text(GTK_CLIST(list), row, 0, &line);
 
   strncpy(my_asclock->selected_theme_filename, line, MAX_PATH_LEN);
+  my_asclock->selected_theme_filename[MAX_PATH_LEN-1] = '\0';
 
   if(strncmp(my_asclock->selected_theme_filename, my_asclock->theme_filename, MAX_PATH_LEN)!=0)
     gnome_property_box_changed( GNOME_PROPERTY_BOX(my_asclock->pwin));
   return;
-  column = 0;
-  event = NULL;
 }
 
 static void location_selected(GtkWidget *list, gint row, gint column, GdkEventButton *event, gpointer data)
@@ -121,11 +119,10 @@ static void location_selected(GtkWidget *list, gint row, gint column, GdkEventBu
   gtk_clist_get_text(GTK_CLIST(list), row, 1, &line);
 
   strncpy(my_asclock->selected_timezone, line, MAX_PATH_LEN);
+  my_asclock->selected_timezone[MAX_PATH_LEN-1] = '\0';
 
   properties_timezone_render(my_asclock, list, my->lat, my->lon);
   return;
-  column = 0;
-  event = NULL;
 }
 
 static asclock *static_my_asclock;
@@ -137,7 +134,7 @@ static void dialog_clicked_cb(GnomeDialog * dialog, gint button_number,
   switch (button_number) {
   case 0: /* OK button */
     /* replace the /etc/localtime link with this timezone */
-    snprintf(cmd, 1024, "rm -f /etc/localtime; ln -s ../usr/share/zoneinfo/%s /etc/localtime", 
+    g_snprintf(cmd, 1024, "rm -f /etc/localtime; ln -s ../usr/share/zoneinfo/%s /etc/localtime", 
 	     static_my_asclock->timezone);
     
     system(cmd);
@@ -149,7 +146,6 @@ static void dialog_clicked_cb(GnomeDialog * dialog, gint button_number,
   };
   gnome_dialog_close(dialog);
   return;
-  data = NULL;
 }
          
 static int property_apply_cb(AppletWidget *applet, gpointer data)
@@ -179,6 +175,7 @@ static int property_apply_cb(AppletWidget *applet, gpointer data)
       }
 
     strncpy(static_my_asclock->timezone, static_my_asclock->selected_timezone, MAX_PATH_LEN);
+    static_my_asclock->timezone[MAX_PATH_LEN-1] = '\0';
 #ifdef HAVE_SETENV
      setenv("TZ", static_my_asclock->timezone, TRUE);
 #else
@@ -207,6 +204,7 @@ static int property_apply_cb(AppletWidget *applet, gpointer data)
     set_clock_pixmap();
   
     strncpy(static_my_asclock->theme_filename, static_my_asclock->selected_theme_filename, MAX_PATH_LEN);
+    static_my_asclock->theme_filename[MAX_PATH_LEN-1] = '\0';
   }
 
   if(static_my_asclock->showampm != static_my_asclock->selected_showampm)
@@ -217,8 +215,6 @@ static int property_apply_cb(AppletWidget *applet, gpointer data)
   static_my_asclock->itblinks = static_my_asclock->selected_itblinks;
 
   return FALSE;
-  data = NULL;
-  applet = NULL;
 }
 
 static int showampm_selected_cb(GtkWidget *b, gpointer data)
@@ -251,7 +247,6 @@ static int property_close_cb(AppletWidget *applet, gpointer data)
   my_asclock->pic = NULL;
 
   return FALSE;
-  applet = NULL;
 }
 
 static void
@@ -433,9 +428,4 @@ void properties_dialog(AppletWidget *applet, gpointer data)
 
   gtk_widget_show_all(my_asclock->pwin);
   return;
-  applet = NULL;
 } 
-
-
-
-
