@@ -6,7 +6,7 @@
  *	desire, and the old great slash applet.
  *	
  *
- *	Authors: Jayson Lorenzen (jslorenzen@earthlink.net)
+ *	Authors: Jayson Lorenzen (jayson_lorenzen@yahoo.com)
  *               Jim Garrison (garrison@users.sourceforge.net)
  *               Rached Blili (striker@Dread.net)
  *
@@ -206,7 +206,7 @@
 		if ( http_got() == -1 || !(configured()) ) {  
 			reSetOutputArray();
 			fprintf(stderr, "No data!\n");
-			setOutputArray("No data available or properties not set");
+			setOutputArray(_("No data available or properties not set"));
 		}
 	}
 
@@ -441,7 +441,7 @@
 
 		if ( CONFIG ) {
 			while ( !feof(CONFIG) ) {
-				fgets(buffer,511,CONFIG);
+				fgets(buffer, sizeof(buffer)-1, CONFIG);
 
 				if (strstr(buffer,
 				    "<td nowrap align=left><a href=\"/q\?s=")) {
@@ -476,7 +476,7 @@
 		gchar *body;
 		gchar *proxy = g_getenv("http_proxy");
 
-		g_snprintf(s_port, 8, "%d", a_port);
+		g_snprintf(s_port, sizeof(s_port), "%d", a_port);
 		uri = g_strconcat("http://", a_host, ":", s_port, 
 						a_resource, NULL);
 
@@ -696,7 +696,7 @@
 	static void about_cb (AppletWidget *widget, gpointer data) {
 		GtkWidget *about;
 		static const gchar *authors[] = {
-			"Jayson Lorenzen <jslorenzen@earthlink.net>",
+			"Jayson Lorenzen <jayson_lorenzen@yahoo.com>",
 			"Jim Garrison <garrison@users.sourceforge.net>",
 			"Rached Blili <striker@dread.net>"
 		};
@@ -968,6 +968,8 @@
 		if ((temp=strtok(syms,"+")))
 			symbol[0] = g_strdup(temp);
 
+		g_free(syms);
+		
 		while (symbol[0]) {
 			gtk_clist_append(GTK_CLIST(clist),symbol);
 			if ((temp=strtok(NULL,"+")))
@@ -980,7 +982,7 @@
 			symbol[0] = g_strdup(temp);
 			gtk_clist_append(GTK_CLIST(clist),symbol);
 		}
-				
+		g_free(temp);		
 	}
 
 	/*-----------------------------------------------------------------*/
@@ -1630,7 +1632,7 @@
 
 
 
-	//------------------------------------------------------------
+	/*------------------------------------------------------------*/
 	void removeSpace(char *buffer) {
 
 		int i;
